@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 #
-package App::PFT::Data::Date v0.04.1;
+package App::PFT::Data::Date v0.04.2;
 
 use strict;
 use warnings;
@@ -52,8 +52,7 @@ sub is_complete {
 
 sub repr {
     my $self = shift;
-    join
-        do { my $sep = shift; defined $sep ? $sep : '-' },
+    join shift || '-',
         ($self->has_year ? sprintf('%04d', $self->year) : '*'),
         ($self->has_month ? sprintf('%02d', $self->month) : '*'),
         ($self->has_day ? sprintf('%02d', $self->day) : '*')
